@@ -3,8 +3,8 @@
 .. todo::
 
     Add tests for I2C communication, as a way to test the main board without I/O
-    board attached to it. The tests provided here assume physical relays are in 
-    place, since it uses the Raspberry Pi GPIOs to assert the relay state. The 
+    board attached to it. The tests provided here assume physical relays are in
+    place, since it uses the Raspberry Pi GPIOs to assert the relay state. The
     I2C bus of the Raspberry Pi can be used for this purpose.
 """
 
@@ -52,7 +52,7 @@ async def setup(AT):
 
 async def test_comms(AT):
     """Test Communications
-    
+
     This function internally uses the ``TESTCOMMS`` cat command.
     """
 
@@ -62,7 +62,7 @@ async def test_comms(AT):
 
 async def test_shtc3(AT):
     """Test SHTC3
-    
+
     This function internally uses the ``TESTSHTC3`` cat command.
     """
 
@@ -119,12 +119,12 @@ async def test_modbus(AT):
         9,
     )
     result = await AT.TESTMODBUS.expect_reply()
-    assert int(result) == 42, 'Modbus returned erroneous result'
+    assert float(result) == 42, 'Modbus returned erroneous result'
 
 
 async def test_buzzer(AT):
     """Test buzzer
-    
+
     This function internally uses the ``TESTBUZZ`` cat command.
     """
 
@@ -137,7 +137,7 @@ async def test_buzzer(AT):
 
 async def test_led(AT):
     """Test LED display
-    
+
     This function internally uses the ``TESTLED`` cat command.
     """
 
@@ -150,7 +150,7 @@ async def test_led(AT):
 
 async def test_pir(AT):
     """Test PIR
-    
+
     This function internally uses the ``TESTPIR`` cat command.
     """
 
@@ -162,7 +162,7 @@ async def test_pir(AT):
 
 async def test_btn(AT):
     """Test button
-    
+
     This function internally uses the ``TESTBTN`` cat command.
     """
 
@@ -186,11 +186,11 @@ async def _test_relay(AT, relay_no: int):
 
     This function internally uses the ``TESTRELAY`` cat command.
 
-    This function first turns off the relay, then turns it on, and finally 
-    turns it off again. At every step it checks through the Raspberry Pi GPIOs 
+    This function first turns off the relay, then turns it on, and finally
+    turns it off again. At every step it checks through the Raspberry Pi GPIOs
     if the relay state is the expected one.
 
-    ``RELAY_COMMON_GPIO`` is used to produce an output signal, and the 
+    ``RELAY_COMMON_GPIO`` is used to produce an output signal, and the
     ``RELAY_GPIO_MAP`` inputs are connected to it through the relays. This way,
     the program can assert if the relay is on or off.
 
